==> qcad-3.32.4.0-2-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id_ID">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Vertikal/Horizontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Kembali</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation type="unfinished">Kustom</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation type="unfinished">Grid</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished">Akhir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">Pada Entitas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished">Tegak lurus</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished">Tangensial</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished">Pusat</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished">Tengah</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished">Persimpangan</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished">Referensi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Jarak</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished">Tidak valid</translation>
    </message>
</context>
</TS>

==> qcad-3.32.6.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id_ID">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikal/Horizontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Kustom</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Grid</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Akhir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Pada Entitas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Tegak lurus</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangensial</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Pusat</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Tengah</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Persimpangan</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referensi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Jarak</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Tidak valid</translation>
    </message>
</context>
</TS>
